/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */

/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */

/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */

/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */


/* Here are the 16 "normal" colors for theming */

+termcolor(0,  nth($colors, 1))
+termcolor(1,  nth($colors, 2))
+termcolor(2,  nth($colors, 3))
+termcolor(3,  nth($colors, 4))
+termcolor(4,  nth($colors, 5))
+termcolor(5,  nth($colors, 6))
+termcolor(6,  nth($colors, 7))
+termcolor(7,  nth($colors, 8))
+termcolor(8,  nth($colors, 9))
+termcolor(9,  nth($colors, 10))
+termcolor(10, nth($colors, 11))
+termcolor(11, nth($colors, 12))
+termcolor(12, nth($colors, 13))
+termcolor(13, nth($colors, 14))
+termcolor(14, nth($colors, 15))
+termcolor(15, nth($colors, 16))
