/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */

/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */

/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */

/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */

/* Here are the 240 xterm colors */
/* See http://upload.wikimedia.org/wikipedia/en/1/15/Xterm_256color_chart.svg */

$st: 00, 95, 135, 175, 215, 255

@for $i from 0 through 215
  $r: nth($st, 1 + floor(($i / 36) % 6))
  $g: nth($st, 1 + floor(($i / 6) % 6))
  $b: nth($st, 1 + $i % 6)
  +termcolor($i + 16, rgb($r, $g, $b))

@for $i from 0 through 23
  $l: 8 + $i * 10
  +termcolor($i + 232, rgb($l, $l, $l))

+termcolor(256, $default-bg)
+termcolor(257, $default-fg)
