/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */

/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */

/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */

/* Variables */

/** Font
$font-family: "SourceCodePro" !default
$font-size: 1em !default
$font-line-height: 1.2 !default

/** Colors */
/* Foreground */
$fg: #f4ead5 !default
/* Background */
$bg: #110f13 !default

$default-bg: transparent !default
$active-bg: transparent !default
$default-fg: $fg !default

$reverse-transparent: $bg !default

/* 16 Colors in this orders: Black, Red, Green, Yellow, Blue, Magenta, Cyan, White, Bright Black, Bright Red, Bright Green, Bright Yellow, Bright Blue, Bright Magenta, Bright Cyan, Bright White */
$colors: #2e3436, #cc0000, #4e9a06, #c4a000, #3465a4, #75507b, #06989a, #d3d7cf, #555753, #ef2929, #8ae234, #fce94f, #729fcf, #ad7fa8, #34e2e2, #eeeeec !default

/** Text effects */

/* The shadow is the size of the blur (in px for instance)
$shadow: 0 !default
/* The shadow alpha is the opacity of the shadow
$shadow-alpha: 0 !default

/** Scroll */
$scroll-bg: $bg !default
$scroll-fg: rgba($fg, .1) !default
$scroll-fg-hover: rgba($fg, .1) !default
$scroll-width: .75em !default

/** Popup */
$popup-bg: rgba(127, 127, 127, .5) !default
$popup-fg: $fg !default
$popup-fs: 1em !default

