/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */

/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */

/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */

/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */

=termcolor($i, $color)
  .bg-color-#{$i}
    background-color: $color
    &.reverse-video
      @if $color == transparent
        color: $reverse-transparent !important
      @else
        color: $color !important

  .fg-color-#{$i}
    color: $color
    &.reverse-video
      background-color: $color !important

    @if $shadow != 0
      text-shadow: 0 0 $shadow rgba($color, $shadow-alpha)
