<!DOCTYPE html>
{% from tornado.options import options %}
<html>
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="Butterfly - A web terminal based on websocket and tornado">
    <meta name="author" content="Mounier Florian">
    <link rel="shortcut icon" href="{{ static_url('images/favicon.png') }}">

    <title>Butterfly</title>
    <link href="{{ static_url('main.css') }}" rel="stylesheet" id="style">
  </head>

  <body spellcheck="false"
        data-force-unicode-width="{{ 'yes' if options.force_unicode_width else 'no' }}"
        data-root-path="{{ options.uri_root_path }}">
    <div id="popup" class="hidden">
    </div>
    <script src="{{ static_url('html-sanitizer.js') }}"></script>
    <script src="{{ static_url('main.%sjs' % (
                 '' if options.unminified else 'min.')) }}"></script>
    <script src="{{ static_url('ext.%sjs' % (
                 '' if options.unminified else 'min.')) }}"></script>
  </body>
</html>
