/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */
/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */
/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */
/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
/* Theses are the various imported style files */
/* THIS NEEDS the python `libsass` library to be installed. */
/* You can copy the imported files in the theme dir, they will be imported prioritarily. */
/* These a the default variables */
/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */
/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */
/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */
/* Variables */
/** Font */
/** Colors */
/* Foreground */
/* Background */
/* 16 Colors in this orders: Black, Red, Green, Yellow, Blue, Magenta, Cyan, White, Bright Black, Bright Red, Bright Green, Bright Yellow, Bright Blue, Bright Magenta, Bright Cyan, Bright White */
/** Text effects */
/* The shadow is the size of the blur (in px for instance) */
/* The shadow alpha is the opacity of the shadow */
/** Scroll */
/** Popup */
/* These are all imported files */
/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */
/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */
/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */
/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
/* Theses are the various imported style files */
/* THIS NEEDS the python `libsass` library to be installed. */
/* You can copy the imported files in the theme dir, they will be imported prioritarily. */
/* You can change this file to import any webfont: */
/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */
/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */
/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */
/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
@font-face {
  font-family: "SourceCodePro";
  src: url("/static/fonts/SourceCodePro-ExtraLight.otf") format("woff");
  font-weight: 100; }

@font-face {
  font-family: "SourceCodePro";
  src: url("/static/fonts/SourceCodePro-Light.otf") format("woff");
  font-weight: 300; }

@font-face {
  font-family: "SourceCodePro";
  src: url("/static/fonts/SourceCodePro-Regular.otf") format("woff");
  font-weight: 400; }

@font-face {
  font-family: "SourceCodePro";
  src: url("/static/fonts/SourceCodePro-Medium.otf") format("woff");
  font-weight: 500; }

@font-face {
  font-family: "SourceCodePro";
  src: url("/static/fonts/SourceCodePro-Semibold.otf") format("woff");
  font-weight: 600; }

@font-face {
  font-family: "SourceCodePro";
  src: url("/static/fonts/SourceCodePro-Bold.otf") format("woff");
  font-weight: 700; }

@font-face {
  font-family: "SourceCodePro";
  src: url("/static/fonts/SourceCodePro-Black.otf") format("woff");
  font-weight: 900; }

body {
  font-family: "SourceCodePro";
  font-size: 1em;
  line-height: 1.2; }

/* You can comment / uncomment the following to enable/disable terminal effects. */
/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */
/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */
/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */
/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
body {
  transition: 200ms;
  transform-origin: bottom; }
  body.bell {
    -webkit-filter: blur(2px);
    filter: blur(2px); }
  body.skip {
    -webkit-filter: sepia(1);
    filter: sepia(1); }
  body.selection {
    -webkit-filter: saturate(2);
    filter: saturate(2); }
  body.alarm {
    -webkit-filter: hue-rotate(150deg);
    filter: hue-rotate(150deg); }
  body.dead {
    -webkit-filter: grayscale(1);
    filter: grayscale(1); }
    body.dead:after {
      content: "CLOSED";
      font-size: 15em;
      display: flex;
      justify-content: center;
      align-items: center;
      position: fixed;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      transform: rotate(-45deg);
      opacity: .2;
      font-weight: 900; }
  body.stopped {
    -webkit-filter: brightness(50%);
    filter: brightness(50%); }
  body.locked::-webkit-scrollbar-thumb {
    background: rgba(255, 0, 0, 0.7); }
  body.locked::-webkit-scrollbar-thumb:hover {
    background: rgba(255, 0, 0, 0.8); }

/* Comment this one to remove the blurry text: */
body {
  text-shadow: 0 0 0 rgba(244, 234, 213, 0); }

/* @import all_fx */
/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */
/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */
/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */
/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
/* The color theme is defined in this one: */
/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */
/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */
/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */
/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
/* Here are the 16 "normal" colors for theming */
.bg-color-0 {
  background-color: #2e3436; }
  .bg-color-0.reverse-video {
    color: #2e3436 !important; }

.fg-color-0 {
  color: #2e3436; }
  .fg-color-0.reverse-video {
    background-color: #2e3436 !important; }

.bg-color-1 {
  background-color: #cc0000; }
  .bg-color-1.reverse-video {
    color: #cc0000 !important; }

.fg-color-1, .nbsp {
  color: #cc0000; }
  .fg-color-1.reverse-video, .reverse-video.nbsp {
    background-color: #cc0000 !important; }

.bg-color-2 {
  background-color: #4e9a06; }
  .bg-color-2.reverse-video {
    color: #4e9a06 !important; }

.fg-color-2 {
  color: #4e9a06; }
  .fg-color-2.reverse-video {
    background-color: #4e9a06 !important; }

.bg-color-3 {
  background-color: #c4a000; }
  .bg-color-3.reverse-video {
    color: #c4a000 !important; }

.fg-color-3 {
  color: #c4a000; }
  .fg-color-3.reverse-video {
    background-color: #c4a000 !important; }

.bg-color-4 {
  background-color: #3465a4; }
  .bg-color-4.reverse-video {
    color: #3465a4 !important; }

.fg-color-4 {
  color: #3465a4; }
  .fg-color-4.reverse-video {
    background-color: #3465a4 !important; }

.bg-color-5 {
  background-color: #75507b; }
  .bg-color-5.reverse-video {
    color: #75507b !important; }

.fg-color-5 {
  color: #75507b; }
  .fg-color-5.reverse-video {
    background-color: #75507b !important; }

.bg-color-6 {
  background-color: #06989a; }
  .bg-color-6.reverse-video {
    color: #06989a !important; }

.fg-color-6 {
  color: #06989a; }
  .fg-color-6.reverse-video {
    background-color: #06989a !important; }

.bg-color-7 {
  background-color: #d3d7cf; }
  .bg-color-7.reverse-video {
    color: #d3d7cf !important; }

.fg-color-7 {
  color: #d3d7cf; }
  .fg-color-7.reverse-video {
    background-color: #d3d7cf !important; }

.bg-color-8 {
  background-color: #555753; }
  .bg-color-8.reverse-video {
    color: #555753 !important; }

.fg-color-8 {
  color: #555753; }
  .fg-color-8.reverse-video {
    background-color: #555753 !important; }

.bg-color-9 {
  background-color: #ef2929; }
  .bg-color-9.reverse-video {
    color: #ef2929 !important; }

.fg-color-9 {
  color: #ef2929; }
  .fg-color-9.reverse-video {
    background-color: #ef2929 !important; }

.bg-color-10 {
  background-color: #8ae234; }
  .bg-color-10.reverse-video {
    color: #8ae234 !important; }

.fg-color-10 {
  color: #8ae234; }
  .fg-color-10.reverse-video {
    background-color: #8ae234 !important; }

.bg-color-11 {
  background-color: #fce94f; }
  .bg-color-11.reverse-video {
    color: #fce94f !important; }

.fg-color-11 {
  color: #fce94f; }
  .fg-color-11.reverse-video {
    background-color: #fce94f !important; }

.bg-color-12 {
  background-color: #729fcf; }
  .bg-color-12.reverse-video {
    color: #729fcf !important; }

.fg-color-12 {
  color: #729fcf; }
  .fg-color-12.reverse-video {
    background-color: #729fcf !important; }

.bg-color-13 {
  background-color: #ad7fa8; }
  .bg-color-13.reverse-video {
    color: #ad7fa8 !important; }

.fg-color-13 {
  color: #ad7fa8; }
  .fg-color-13.reverse-video {
    background-color: #ad7fa8 !important; }

.bg-color-14 {
  background-color: #34e2e2; }
  .bg-color-14.reverse-video {
    color: #34e2e2 !important; }

.fg-color-14 {
  color: #34e2e2; }
  .fg-color-14.reverse-video {
    background-color: #34e2e2 !important; }

.bg-color-15 {
  background-color: #eeeeec; }
  .bg-color-15.reverse-video {
    color: #eeeeec !important; }

.fg-color-15 {
  color: #eeeeec; }
  .fg-color-15.reverse-video {
    background-color: #eeeeec !important; }

/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */
/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */
/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */
/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
/* Here are the 240 xterm colors */
/* See http://upload.wikimedia.org/wikipedia/en/1/15/Xterm_256color_chart.svg */
.bg-color-16 {
  background-color: black; }
  .bg-color-16.reverse-video {
    color: black !important; }

.fg-color-16 {
  color: black; }
  .fg-color-16.reverse-video {
    background-color: black !important; }

.bg-color-17 {
  background-color: #00005f; }
  .bg-color-17.reverse-video {
    color: #00005f !important; }

.fg-color-17 {
  color: #00005f; }
  .fg-color-17.reverse-video {
    background-color: #00005f !important; }

.bg-color-18 {
  background-color: #000087; }
  .bg-color-18.reverse-video {
    color: #000087 !important; }

.fg-color-18 {
  color: #000087; }
  .fg-color-18.reverse-video {
    background-color: #000087 !important; }

.bg-color-19 {
  background-color: #0000af; }
  .bg-color-19.reverse-video {
    color: #0000af !important; }

.fg-color-19 {
  color: #0000af; }
  .fg-color-19.reverse-video {
    background-color: #0000af !important; }

.bg-color-20 {
  background-color: #0000d7; }
  .bg-color-20.reverse-video {
    color: #0000d7 !important; }

.fg-color-20 {
  color: #0000d7; }
  .fg-color-20.reverse-video {
    background-color: #0000d7 !important; }

.bg-color-21 {
  background-color: blue; }
  .bg-color-21.reverse-video {
    color: blue !important; }

.fg-color-21 {
  color: blue; }
  .fg-color-21.reverse-video {
    background-color: blue !important; }

.bg-color-22 {
  background-color: #005f00; }
  .bg-color-22.reverse-video {
    color: #005f00 !important; }

.fg-color-22 {
  color: #005f00; }
  .fg-color-22.reverse-video {
    background-color: #005f00 !important; }

.bg-color-23 {
  background-color: #005f5f; }
  .bg-color-23.reverse-video {
    color: #005f5f !important; }

.fg-color-23 {
  color: #005f5f; }
  .fg-color-23.reverse-video {
    background-color: #005f5f !important; }

.bg-color-24 {
  background-color: #005f87; }
  .bg-color-24.reverse-video {
    color: #005f87 !important; }

.fg-color-24 {
  color: #005f87; }
  .fg-color-24.reverse-video {
    background-color: #005f87 !important; }

.bg-color-25 {
  background-color: #005faf; }
  .bg-color-25.reverse-video {
    color: #005faf !important; }

.fg-color-25 {
  color: #005faf; }
  .fg-color-25.reverse-video {
    background-color: #005faf !important; }

.bg-color-26 {
  background-color: #005fd7; }
  .bg-color-26.reverse-video {
    color: #005fd7 !important; }

.fg-color-26 {
  color: #005fd7; }
  .fg-color-26.reverse-video {
    background-color: #005fd7 !important; }

.bg-color-27 {
  background-color: #005fff; }
  .bg-color-27.reverse-video {
    color: #005fff !important; }

.fg-color-27 {
  color: #005fff; }
  .fg-color-27.reverse-video {
    background-color: #005fff !important; }

.bg-color-28 {
  background-color: #008700; }
  .bg-color-28.reverse-video {
    color: #008700 !important; }

.fg-color-28 {
  color: #008700; }
  .fg-color-28.reverse-video {
    background-color: #008700 !important; }

.bg-color-29 {
  background-color: #00875f; }
  .bg-color-29.reverse-video {
    color: #00875f !important; }

.fg-color-29 {
  color: #00875f; }
  .fg-color-29.reverse-video {
    background-color: #00875f !important; }

.bg-color-30 {
  background-color: #008787; }
  .bg-color-30.reverse-video {
    color: #008787 !important; }

.fg-color-30 {
  color: #008787; }
  .fg-color-30.reverse-video {
    background-color: #008787 !important; }

.bg-color-31 {
  background-color: #0087af; }
  .bg-color-31.reverse-video {
    color: #0087af !important; }

.fg-color-31 {
  color: #0087af; }
  .fg-color-31.reverse-video {
    background-color: #0087af !important; }

.bg-color-32 {
  background-color: #0087d7; }
  .bg-color-32.reverse-video {
    color: #0087d7 !important; }

.fg-color-32 {
  color: #0087d7; }
  .fg-color-32.reverse-video {
    background-color: #0087d7 !important; }

.bg-color-33 {
  background-color: #0087ff; }
  .bg-color-33.reverse-video {
    color: #0087ff !important; }

.fg-color-33 {
  color: #0087ff; }
  .fg-color-33.reverse-video {
    background-color: #0087ff !important; }

.bg-color-34 {
  background-color: #00af00; }
  .bg-color-34.reverse-video {
    color: #00af00 !important; }

.fg-color-34 {
  color: #00af00; }
  .fg-color-34.reverse-video {
    background-color: #00af00 !important; }

.bg-color-35 {
  background-color: #00af5f; }
  .bg-color-35.reverse-video {
    color: #00af5f !important; }

.fg-color-35 {
  color: #00af5f; }
  .fg-color-35.reverse-video {
    background-color: #00af5f !important; }

.bg-color-36 {
  background-color: #00af87; }
  .bg-color-36.reverse-video {
    color: #00af87 !important; }

.fg-color-36 {
  color: #00af87; }
  .fg-color-36.reverse-video {
    background-color: #00af87 !important; }

.bg-color-37 {
  background-color: #00afaf; }
  .bg-color-37.reverse-video {
    color: #00afaf !important; }

.fg-color-37 {
  color: #00afaf; }
  .fg-color-37.reverse-video {
    background-color: #00afaf !important; }

.bg-color-38 {
  background-color: #00afd7; }
  .bg-color-38.reverse-video {
    color: #00afd7 !important; }

.fg-color-38 {
  color: #00afd7; }
  .fg-color-38.reverse-video {
    background-color: #00afd7 !important; }

.bg-color-39 {
  background-color: #00afff; }
  .bg-color-39.reverse-video {
    color: #00afff !important; }

.fg-color-39 {
  color: #00afff; }
  .fg-color-39.reverse-video {
    background-color: #00afff !important; }

.bg-color-40 {
  background-color: #00d700; }
  .bg-color-40.reverse-video {
    color: #00d700 !important; }

.fg-color-40 {
  color: #00d700; }
  .fg-color-40.reverse-video {
    background-color: #00d700 !important; }

.bg-color-41 {
  background-color: #00d75f; }
  .bg-color-41.reverse-video {
    color: #00d75f !important; }

.fg-color-41 {
  color: #00d75f; }
  .fg-color-41.reverse-video {
    background-color: #00d75f !important; }

.bg-color-42 {
  background-color: #00d787; }
  .bg-color-42.reverse-video {
    color: #00d787 !important; }

.fg-color-42 {
  color: #00d787; }
  .fg-color-42.reverse-video {
    background-color: #00d787 !important; }

.bg-color-43 {
  background-color: #00d7af; }
  .bg-color-43.reverse-video {
    color: #00d7af !important; }

.fg-color-43 {
  color: #00d7af; }
  .fg-color-43.reverse-video {
    background-color: #00d7af !important; }

.bg-color-44 {
  background-color: #00d7d7; }
  .bg-color-44.reverse-video {
    color: #00d7d7 !important; }

.fg-color-44 {
  color: #00d7d7; }
  .fg-color-44.reverse-video {
    background-color: #00d7d7 !important; }

.bg-color-45 {
  background-color: #00d7ff; }
  .bg-color-45.reverse-video {
    color: #00d7ff !important; }

.fg-color-45 {
  color: #00d7ff; }
  .fg-color-45.reverse-video {
    background-color: #00d7ff !important; }

.bg-color-46 {
  background-color: lime; }
  .bg-color-46.reverse-video {
    color: lime !important; }

.fg-color-46 {
  color: lime; }
  .fg-color-46.reverse-video {
    background-color: lime !important; }

.bg-color-47 {
  background-color: #00ff5f; }
  .bg-color-47.reverse-video {
    color: #00ff5f !important; }

.fg-color-47 {
  color: #00ff5f; }
  .fg-color-47.reverse-video {
    background-color: #00ff5f !important; }

.bg-color-48 {
  background-color: #00ff87; }
  .bg-color-48.reverse-video {
    color: #00ff87 !important; }

.fg-color-48 {
  color: #00ff87; }
  .fg-color-48.reverse-video {
    background-color: #00ff87 !important; }

.bg-color-49 {
  background-color: #00ffaf; }
  .bg-color-49.reverse-video {
    color: #00ffaf !important; }

.fg-color-49 {
  color: #00ffaf; }
  .fg-color-49.reverse-video {
    background-color: #00ffaf !important; }

.bg-color-50 {
  background-color: #00ffd7; }
  .bg-color-50.reverse-video {
    color: #00ffd7 !important; }

.fg-color-50 {
  color: #00ffd7; }
  .fg-color-50.reverse-video {
    background-color: #00ffd7 !important; }

.bg-color-51 {
  background-color: cyan; }
  .bg-color-51.reverse-video {
    color: cyan !important; }

.fg-color-51 {
  color: cyan; }
  .fg-color-51.reverse-video {
    background-color: cyan !important; }

.bg-color-52 {
  background-color: #5f0000; }
  .bg-color-52.reverse-video {
    color: #5f0000 !important; }

.fg-color-52 {
  color: #5f0000; }
  .fg-color-52.reverse-video {
    background-color: #5f0000 !important; }

.bg-color-53 {
  background-color: #5f005f; }
  .bg-color-53.reverse-video {
    color: #5f005f !important; }

.fg-color-53 {
  color: #5f005f; }
  .fg-color-53.reverse-video {
    background-color: #5f005f !important; }

.bg-color-54 {
  background-color: #5f0087; }
  .bg-color-54.reverse-video {
    color: #5f0087 !important; }

.fg-color-54 {
  color: #5f0087; }
  .fg-color-54.reverse-video {
    background-color: #5f0087 !important; }

.bg-color-55 {
  background-color: #5f00af; }
  .bg-color-55.reverse-video {
    color: #5f00af !important; }

.fg-color-55 {
  color: #5f00af; }
  .fg-color-55.reverse-video {
    background-color: #5f00af !important; }

.bg-color-56 {
  background-color: #5f00d7; }
  .bg-color-56.reverse-video {
    color: #5f00d7 !important; }

.fg-color-56 {
  color: #5f00d7; }
  .fg-color-56.reverse-video {
    background-color: #5f00d7 !important; }

.bg-color-57 {
  background-color: #5f00ff; }
  .bg-color-57.reverse-video {
    color: #5f00ff !important; }

.fg-color-57 {
  color: #5f00ff; }
  .fg-color-57.reverse-video {
    background-color: #5f00ff !important; }

.bg-color-58 {
  background-color: #5f5f00; }
  .bg-color-58.reverse-video {
    color: #5f5f00 !important; }

.fg-color-58 {
  color: #5f5f00; }
  .fg-color-58.reverse-video {
    background-color: #5f5f00 !important; }

.bg-color-59 {
  background-color: #5f5f5f; }
  .bg-color-59.reverse-video {
    color: #5f5f5f !important; }

.fg-color-59 {
  color: #5f5f5f; }
  .fg-color-59.reverse-video {
    background-color: #5f5f5f !important; }

.bg-color-60 {
  background-color: #5f5f87; }
  .bg-color-60.reverse-video {
    color: #5f5f87 !important; }

.fg-color-60 {
  color: #5f5f87; }
  .fg-color-60.reverse-video {
    background-color: #5f5f87 !important; }

.bg-color-61 {
  background-color: #5f5faf; }
  .bg-color-61.reverse-video {
    color: #5f5faf !important; }

.fg-color-61 {
  color: #5f5faf; }
  .fg-color-61.reverse-video {
    background-color: #5f5faf !important; }

.bg-color-62 {
  background-color: #5f5fd7; }
  .bg-color-62.reverse-video {
    color: #5f5fd7 !important; }

.fg-color-62 {
  color: #5f5fd7; }
  .fg-color-62.reverse-video {
    background-color: #5f5fd7 !important; }

.bg-color-63 {
  background-color: #5f5fff; }
  .bg-color-63.reverse-video {
    color: #5f5fff !important; }

.fg-color-63 {
  color: #5f5fff; }
  .fg-color-63.reverse-video {
    background-color: #5f5fff !important; }

.bg-color-64 {
  background-color: #5f8700; }
  .bg-color-64.reverse-video {
    color: #5f8700 !important; }

.fg-color-64 {
  color: #5f8700; }
  .fg-color-64.reverse-video {
    background-color: #5f8700 !important; }

.bg-color-65 {
  background-color: #5f875f; }
  .bg-color-65.reverse-video {
    color: #5f875f !important; }

.fg-color-65 {
  color: #5f875f; }
  .fg-color-65.reverse-video {
    background-color: #5f875f !important; }

.bg-color-66 {
  background-color: #5f8787; }
  .bg-color-66.reverse-video {
    color: #5f8787 !important; }

.fg-color-66 {
  color: #5f8787; }
  .fg-color-66.reverse-video {
    background-color: #5f8787 !important; }

.bg-color-67 {
  background-color: #5f87af; }
  .bg-color-67.reverse-video {
    color: #5f87af !important; }

.fg-color-67 {
  color: #5f87af; }
  .fg-color-67.reverse-video {
    background-color: #5f87af !important; }

.bg-color-68 {
  background-color: #5f87d7; }
  .bg-color-68.reverse-video {
    color: #5f87d7 !important; }

.fg-color-68 {
  color: #5f87d7; }
  .fg-color-68.reverse-video {
    background-color: #5f87d7 !important; }

.bg-color-69 {
  background-color: #5f87ff; }
  .bg-color-69.reverse-video {
    color: #5f87ff !important; }

.fg-color-69 {
  color: #5f87ff; }
  .fg-color-69.reverse-video {
    background-color: #5f87ff !important; }

.bg-color-70 {
  background-color: #5faf00; }
  .bg-color-70.reverse-video {
    color: #5faf00 !important; }

.fg-color-70 {
  color: #5faf00; }
  .fg-color-70.reverse-video {
    background-color: #5faf00 !important; }

.bg-color-71 {
  background-color: #5faf5f; }
  .bg-color-71.reverse-video {
    color: #5faf5f !important; }

.fg-color-71 {
  color: #5faf5f; }
  .fg-color-71.reverse-video {
    background-color: #5faf5f !important; }

.bg-color-72 {
  background-color: #5faf87; }
  .bg-color-72.reverse-video {
    color: #5faf87 !important; }

.fg-color-72 {
  color: #5faf87; }
  .fg-color-72.reverse-video {
    background-color: #5faf87 !important; }

.bg-color-73 {
  background-color: #5fafaf; }
  .bg-color-73.reverse-video {
    color: #5fafaf !important; }

.fg-color-73 {
  color: #5fafaf; }
  .fg-color-73.reverse-video {
    background-color: #5fafaf !important; }

.bg-color-74 {
  background-color: #5fafd7; }
  .bg-color-74.reverse-video {
    color: #5fafd7 !important; }

.fg-color-74 {
  color: #5fafd7; }
  .fg-color-74.reverse-video {
    background-color: #5fafd7 !important; }

.bg-color-75 {
  background-color: #5fafff; }
  .bg-color-75.reverse-video {
    color: #5fafff !important; }

.fg-color-75 {
  color: #5fafff; }
  .fg-color-75.reverse-video {
    background-color: #5fafff !important; }

.bg-color-76 {
  background-color: #5fd700; }
  .bg-color-76.reverse-video {
    color: #5fd700 !important; }

.fg-color-76 {
  color: #5fd700; }
  .fg-color-76.reverse-video {
    background-color: #5fd700 !important; }

.bg-color-77 {
  background-color: #5fd75f; }
  .bg-color-77.reverse-video {
    color: #5fd75f !important; }

.fg-color-77 {
  color: #5fd75f; }
  .fg-color-77.reverse-video {
    background-color: #5fd75f !important; }

.bg-color-78 {
  background-color: #5fd787; }
  .bg-color-78.reverse-video {
    color: #5fd787 !important; }

.fg-color-78 {
  color: #5fd787; }
  .fg-color-78.reverse-video {
    background-color: #5fd787 !important; }

.bg-color-79 {
  background-color: #5fd7af; }
  .bg-color-79.reverse-video {
    color: #5fd7af !important; }

.fg-color-79 {
  color: #5fd7af; }
  .fg-color-79.reverse-video {
    background-color: #5fd7af !important; }

.bg-color-80 {
  background-color: #5fd7d7; }
  .bg-color-80.reverse-video {
    color: #5fd7d7 !important; }

.fg-color-80 {
  color: #5fd7d7; }
  .fg-color-80.reverse-video {
    background-color: #5fd7d7 !important; }

.bg-color-81 {
  background-color: #5fd7ff; }
  .bg-color-81.reverse-video {
    color: #5fd7ff !important; }

.fg-color-81 {
  color: #5fd7ff; }
  .fg-color-81.reverse-video {
    background-color: #5fd7ff !important; }

.bg-color-82 {
  background-color: #5fff00; }
  .bg-color-82.reverse-video {
    color: #5fff00 !important; }

.fg-color-82 {
  color: #5fff00; }
  .fg-color-82.reverse-video {
    background-color: #5fff00 !important; }

.bg-color-83 {
  background-color: #5fff5f; }
  .bg-color-83.reverse-video {
    color: #5fff5f !important; }

.fg-color-83 {
  color: #5fff5f; }
  .fg-color-83.reverse-video {
    background-color: #5fff5f !important; }

.bg-color-84 {
  background-color: #5fff87; }
  .bg-color-84.reverse-video {
    color: #5fff87 !important; }

.fg-color-84 {
  color: #5fff87; }
  .fg-color-84.reverse-video {
    background-color: #5fff87 !important; }

.bg-color-85 {
  background-color: #5fffaf; }
  .bg-color-85.reverse-video {
    color: #5fffaf !important; }

.fg-color-85 {
  color: #5fffaf; }
  .fg-color-85.reverse-video {
    background-color: #5fffaf !important; }

.bg-color-86 {
  background-color: #5fffd7; }
  .bg-color-86.reverse-video {
    color: #5fffd7 !important; }

.fg-color-86 {
  color: #5fffd7; }
  .fg-color-86.reverse-video {
    background-color: #5fffd7 !important; }

.bg-color-87 {
  background-color: #5fffff; }
  .bg-color-87.reverse-video {
    color: #5fffff !important; }

.fg-color-87 {
  color: #5fffff; }
  .fg-color-87.reverse-video {
    background-color: #5fffff !important; }

.bg-color-88 {
  background-color: #870000; }
  .bg-color-88.reverse-video {
    color: #870000 !important; }

.fg-color-88 {
  color: #870000; }
  .fg-color-88.reverse-video {
    background-color: #870000 !important; }

.bg-color-89 {
  background-color: #87005f; }
  .bg-color-89.reverse-video {
    color: #87005f !important; }

.fg-color-89 {
  color: #87005f; }
  .fg-color-89.reverse-video {
    background-color: #87005f !important; }

.bg-color-90 {
  background-color: #870087; }
  .bg-color-90.reverse-video {
    color: #870087 !important; }

.fg-color-90 {
  color: #870087; }
  .fg-color-90.reverse-video {
    background-color: #870087 !important; }

.bg-color-91 {
  background-color: #8700af; }
  .bg-color-91.reverse-video {
    color: #8700af !important; }

.fg-color-91 {
  color: #8700af; }
  .fg-color-91.reverse-video {
    background-color: #8700af !important; }

.bg-color-92 {
  background-color: #8700d7; }
  .bg-color-92.reverse-video {
    color: #8700d7 !important; }

.fg-color-92 {
  color: #8700d7; }
  .fg-color-92.reverse-video {
    background-color: #8700d7 !important; }

.bg-color-93 {
  background-color: #8700ff; }
  .bg-color-93.reverse-video {
    color: #8700ff !important; }

.fg-color-93 {
  color: #8700ff; }
  .fg-color-93.reverse-video {
    background-color: #8700ff !important; }

.bg-color-94 {
  background-color: #875f00; }
  .bg-color-94.reverse-video {
    color: #875f00 !important; }

.fg-color-94 {
  color: #875f00; }
  .fg-color-94.reverse-video {
    background-color: #875f00 !important; }

.bg-color-95 {
  background-color: #875f5f; }
  .bg-color-95.reverse-video {
    color: #875f5f !important; }

.fg-color-95 {
  color: #875f5f; }
  .fg-color-95.reverse-video {
    background-color: #875f5f !important; }

.bg-color-96 {
  background-color: #875f87; }
  .bg-color-96.reverse-video {
    color: #875f87 !important; }

.fg-color-96 {
  color: #875f87; }
  .fg-color-96.reverse-video {
    background-color: #875f87 !important; }

.bg-color-97 {
  background-color: #875faf; }
  .bg-color-97.reverse-video {
    color: #875faf !important; }

.fg-color-97 {
  color: #875faf; }
  .fg-color-97.reverse-video {
    background-color: #875faf !important; }

.bg-color-98 {
  background-color: #875fd7; }
  .bg-color-98.reverse-video {
    color: #875fd7 !important; }

.fg-color-98 {
  color: #875fd7; }
  .fg-color-98.reverse-video {
    background-color: #875fd7 !important; }

.bg-color-99 {
  background-color: #875fff; }
  .bg-color-99.reverse-video {
    color: #875fff !important; }

.fg-color-99 {
  color: #875fff; }
  .fg-color-99.reverse-video {
    background-color: #875fff !important; }

.bg-color-100 {
  background-color: #878700; }
  .bg-color-100.reverse-video {
    color: #878700 !important; }

.fg-color-100 {
  color: #878700; }
  .fg-color-100.reverse-video {
    background-color: #878700 !important; }

.bg-color-101 {
  background-color: #87875f; }
  .bg-color-101.reverse-video {
    color: #87875f !important; }

.fg-color-101 {
  color: #87875f; }
  .fg-color-101.reverse-video {
    background-color: #87875f !important; }

.bg-color-102 {
  background-color: #878787; }
  .bg-color-102.reverse-video {
    color: #878787 !important; }

.fg-color-102 {
  color: #878787; }
  .fg-color-102.reverse-video {
    background-color: #878787 !important; }

.bg-color-103 {
  background-color: #8787af; }
  .bg-color-103.reverse-video {
    color: #8787af !important; }

.fg-color-103 {
  color: #8787af; }
  .fg-color-103.reverse-video {
    background-color: #8787af !important; }

.bg-color-104 {
  background-color: #8787d7; }
  .bg-color-104.reverse-video {
    color: #8787d7 !important; }

.fg-color-104 {
  color: #8787d7; }
  .fg-color-104.reverse-video {
    background-color: #8787d7 !important; }

.bg-color-105 {
  background-color: #8787ff; }
  .bg-color-105.reverse-video {
    color: #8787ff !important; }

.fg-color-105 {
  color: #8787ff; }
  .fg-color-105.reverse-video {
    background-color: #8787ff !important; }

.bg-color-106 {
  background-color: #87af00; }
  .bg-color-106.reverse-video {
    color: #87af00 !important; }

.fg-color-106 {
  color: #87af00; }
  .fg-color-106.reverse-video {
    background-color: #87af00 !important; }

.bg-color-107 {
  background-color: #87af5f; }
  .bg-color-107.reverse-video {
    color: #87af5f !important; }

.fg-color-107 {
  color: #87af5f; }
  .fg-color-107.reverse-video {
    background-color: #87af5f !important; }

.bg-color-108 {
  background-color: #87af87; }
  .bg-color-108.reverse-video {
    color: #87af87 !important; }

.fg-color-108 {
  color: #87af87; }
  .fg-color-108.reverse-video {
    background-color: #87af87 !important; }

.bg-color-109 {
  background-color: #87afaf; }
  .bg-color-109.reverse-video {
    color: #87afaf !important; }

.fg-color-109 {
  color: #87afaf; }
  .fg-color-109.reverse-video {
    background-color: #87afaf !important; }

.bg-color-110 {
  background-color: #87afd7; }
  .bg-color-110.reverse-video {
    color: #87afd7 !important; }

.fg-color-110 {
  color: #87afd7; }
  .fg-color-110.reverse-video {
    background-color: #87afd7 !important; }

.bg-color-111 {
  background-color: #87afff; }
  .bg-color-111.reverse-video {
    color: #87afff !important; }

.fg-color-111 {
  color: #87afff; }
  .fg-color-111.reverse-video {
    background-color: #87afff !important; }

.bg-color-112 {
  background-color: #87d700; }
  .bg-color-112.reverse-video {
    color: #87d700 !important; }

.fg-color-112 {
  color: #87d700; }
  .fg-color-112.reverse-video {
    background-color: #87d700 !important; }

.bg-color-113 {
  background-color: #87d75f; }
  .bg-color-113.reverse-video {
    color: #87d75f !important; }

.fg-color-113 {
  color: #87d75f; }
  .fg-color-113.reverse-video {
    background-color: #87d75f !important; }

.bg-color-114 {
  background-color: #87d787; }
  .bg-color-114.reverse-video {
    color: #87d787 !important; }

.fg-color-114 {
  color: #87d787; }
  .fg-color-114.reverse-video {
    background-color: #87d787 !important; }

.bg-color-115 {
  background-color: #87d7af; }
  .bg-color-115.reverse-video {
    color: #87d7af !important; }

.fg-color-115 {
  color: #87d7af; }
  .fg-color-115.reverse-video {
    background-color: #87d7af !important; }

.bg-color-116 {
  background-color: #87d7d7; }
  .bg-color-116.reverse-video {
    color: #87d7d7 !important; }

.fg-color-116 {
  color: #87d7d7; }
  .fg-color-116.reverse-video {
    background-color: #87d7d7 !important; }

.bg-color-117 {
  background-color: #87d7ff; }
  .bg-color-117.reverse-video {
    color: #87d7ff !important; }

.fg-color-117 {
  color: #87d7ff; }
  .fg-color-117.reverse-video {
    background-color: #87d7ff !important; }

.bg-color-118 {
  background-color: #87ff00; }
  .bg-color-118.reverse-video {
    color: #87ff00 !important; }

.fg-color-118 {
  color: #87ff00; }
  .fg-color-118.reverse-video {
    background-color: #87ff00 !important; }

.bg-color-119 {
  background-color: #87ff5f; }
  .bg-color-119.reverse-video {
    color: #87ff5f !important; }

.fg-color-119 {
  color: #87ff5f; }
  .fg-color-119.reverse-video {
    background-color: #87ff5f !important; }

.bg-color-120 {
  background-color: #87ff87; }
  .bg-color-120.reverse-video {
    color: #87ff87 !important; }

.fg-color-120 {
  color: #87ff87; }
  .fg-color-120.reverse-video {
    background-color: #87ff87 !important; }

.bg-color-121 {
  background-color: #87ffaf; }
  .bg-color-121.reverse-video {
    color: #87ffaf !important; }

.fg-color-121 {
  color: #87ffaf; }
  .fg-color-121.reverse-video {
    background-color: #87ffaf !important; }

.bg-color-122 {
  background-color: #87ffd7; }
  .bg-color-122.reverse-video {
    color: #87ffd7 !important; }

.fg-color-122 {
  color: #87ffd7; }
  .fg-color-122.reverse-video {
    background-color: #87ffd7 !important; }

.bg-color-123 {
  background-color: #87ffff; }
  .bg-color-123.reverse-video {
    color: #87ffff !important; }

.fg-color-123 {
  color: #87ffff; }
  .fg-color-123.reverse-video {
    background-color: #87ffff !important; }

.bg-color-124 {
  background-color: #af0000; }
  .bg-color-124.reverse-video {
    color: #af0000 !important; }

.fg-color-124 {
  color: #af0000; }
  .fg-color-124.reverse-video {
    background-color: #af0000 !important; }

.bg-color-125 {
  background-color: #af005f; }
  .bg-color-125.reverse-video {
    color: #af005f !important; }

.fg-color-125 {
  color: #af005f; }
  .fg-color-125.reverse-video {
    background-color: #af005f !important; }

.bg-color-126 {
  background-color: #af0087; }
  .bg-color-126.reverse-video {
    color: #af0087 !important; }

.fg-color-126 {
  color: #af0087; }
  .fg-color-126.reverse-video {
    background-color: #af0087 !important; }

.bg-color-127 {
  background-color: #af00af; }
  .bg-color-127.reverse-video {
    color: #af00af !important; }

.fg-color-127 {
  color: #af00af; }
  .fg-color-127.reverse-video {
    background-color: #af00af !important; }

.bg-color-128 {
  background-color: #af00d7; }
  .bg-color-128.reverse-video {
    color: #af00d7 !important; }

.fg-color-128 {
  color: #af00d7; }
  .fg-color-128.reverse-video {
    background-color: #af00d7 !important; }

.bg-color-129 {
  background-color: #af00ff; }
  .bg-color-129.reverse-video {
    color: #af00ff !important; }

.fg-color-129 {
  color: #af00ff; }
  .fg-color-129.reverse-video {
    background-color: #af00ff !important; }

.bg-color-130 {
  background-color: #af5f00; }
  .bg-color-130.reverse-video {
    color: #af5f00 !important; }

.fg-color-130 {
  color: #af5f00; }
  .fg-color-130.reverse-video {
    background-color: #af5f00 !important; }

.bg-color-131 {
  background-color: #af5f5f; }
  .bg-color-131.reverse-video {
    color: #af5f5f !important; }

.fg-color-131 {
  color: #af5f5f; }
  .fg-color-131.reverse-video {
    background-color: #af5f5f !important; }

.bg-color-132 {
  background-color: #af5f87; }
  .bg-color-132.reverse-video {
    color: #af5f87 !important; }

.fg-color-132 {
  color: #af5f87; }
  .fg-color-132.reverse-video {
    background-color: #af5f87 !important; }

.bg-color-133 {
  background-color: #af5faf; }
  .bg-color-133.reverse-video {
    color: #af5faf !important; }

.fg-color-133 {
  color: #af5faf; }
  .fg-color-133.reverse-video {
    background-color: #af5faf !important; }

.bg-color-134 {
  background-color: #af5fd7; }
  .bg-color-134.reverse-video {
    color: #af5fd7 !important; }

.fg-color-134 {
  color: #af5fd7; }
  .fg-color-134.reverse-video {
    background-color: #af5fd7 !important; }

.bg-color-135 {
  background-color: #af5fff; }
  .bg-color-135.reverse-video {
    color: #af5fff !important; }

.fg-color-135 {
  color: #af5fff; }
  .fg-color-135.reverse-video {
    background-color: #af5fff !important; }

.bg-color-136 {
  background-color: #af8700; }
  .bg-color-136.reverse-video {
    color: #af8700 !important; }

.fg-color-136 {
  color: #af8700; }
  .fg-color-136.reverse-video {
    background-color: #af8700 !important; }

.bg-color-137 {
  background-color: #af875f; }
  .bg-color-137.reverse-video {
    color: #af875f !important; }

.fg-color-137 {
  color: #af875f; }
  .fg-color-137.reverse-video {
    background-color: #af875f !important; }

.bg-color-138 {
  background-color: #af8787; }
  .bg-color-138.reverse-video {
    color: #af8787 !important; }

.fg-color-138 {
  color: #af8787; }
  .fg-color-138.reverse-video {
    background-color: #af8787 !important; }

.bg-color-139 {
  background-color: #af87af; }
  .bg-color-139.reverse-video {
    color: #af87af !important; }

.fg-color-139 {
  color: #af87af; }
  .fg-color-139.reverse-video {
    background-color: #af87af !important; }

.bg-color-140 {
  background-color: #af87d7; }
  .bg-color-140.reverse-video {
    color: #af87d7 !important; }

.fg-color-140 {
  color: #af87d7; }
  .fg-color-140.reverse-video {
    background-color: #af87d7 !important; }

.bg-color-141 {
  background-color: #af87ff; }
  .bg-color-141.reverse-video {
    color: #af87ff !important; }

.fg-color-141 {
  color: #af87ff; }
  .fg-color-141.reverse-video {
    background-color: #af87ff !important; }

.bg-color-142 {
  background-color: #afaf00; }
  .bg-color-142.reverse-video {
    color: #afaf00 !important; }

.fg-color-142 {
  color: #afaf00; }
  .fg-color-142.reverse-video {
    background-color: #afaf00 !important; }

.bg-color-143 {
  background-color: #afaf5f; }
  .bg-color-143.reverse-video {
    color: #afaf5f !important; }

.fg-color-143 {
  color: #afaf5f; }
  .fg-color-143.reverse-video {
    background-color: #afaf5f !important; }

.bg-color-144 {
  background-color: #afaf87; }
  .bg-color-144.reverse-video {
    color: #afaf87 !important; }

.fg-color-144 {
  color: #afaf87; }
  .fg-color-144.reverse-video {
    background-color: #afaf87 !important; }

.bg-color-145 {
  background-color: #afafaf; }
  .bg-color-145.reverse-video {
    color: #afafaf !important; }

.fg-color-145 {
  color: #afafaf; }
  .fg-color-145.reverse-video {
    background-color: #afafaf !important; }

.bg-color-146 {
  background-color: #afafd7; }
  .bg-color-146.reverse-video {
    color: #afafd7 !important; }

.fg-color-146 {
  color: #afafd7; }
  .fg-color-146.reverse-video {
    background-color: #afafd7 !important; }

.bg-color-147 {
  background-color: #afafff; }
  .bg-color-147.reverse-video {
    color: #afafff !important; }

.fg-color-147 {
  color: #afafff; }
  .fg-color-147.reverse-video {
    background-color: #afafff !important; }

.bg-color-148 {
  background-color: #afd700; }
  .bg-color-148.reverse-video {
    color: #afd700 !important; }

.fg-color-148 {
  color: #afd700; }
  .fg-color-148.reverse-video {
    background-color: #afd700 !important; }

.bg-color-149 {
  background-color: #afd75f; }
  .bg-color-149.reverse-video {
    color: #afd75f !important; }

.fg-color-149 {
  color: #afd75f; }
  .fg-color-149.reverse-video {
    background-color: #afd75f !important; }

.bg-color-150 {
  background-color: #afd787; }
  .bg-color-150.reverse-video {
    color: #afd787 !important; }

.fg-color-150 {
  color: #afd787; }
  .fg-color-150.reverse-video {
    background-color: #afd787 !important; }

.bg-color-151 {
  background-color: #afd7af; }
  .bg-color-151.reverse-video {
    color: #afd7af !important; }

.fg-color-151 {
  color: #afd7af; }
  .fg-color-151.reverse-video {
    background-color: #afd7af !important; }

.bg-color-152 {
  background-color: #afd7d7; }
  .bg-color-152.reverse-video {
    color: #afd7d7 !important; }

.fg-color-152 {
  color: #afd7d7; }
  .fg-color-152.reverse-video {
    background-color: #afd7d7 !important; }

.bg-color-153 {
  background-color: #afd7ff; }
  .bg-color-153.reverse-video {
    color: #afd7ff !important; }

.fg-color-153 {
  color: #afd7ff; }
  .fg-color-153.reverse-video {
    background-color: #afd7ff !important; }

.bg-color-154 {
  background-color: #afff00; }
  .bg-color-154.reverse-video {
    color: #afff00 !important; }

.fg-color-154 {
  color: #afff00; }
  .fg-color-154.reverse-video {
    background-color: #afff00 !important; }

.bg-color-155 {
  background-color: #afff5f; }
  .bg-color-155.reverse-video {
    color: #afff5f !important; }

.fg-color-155 {
  color: #afff5f; }
  .fg-color-155.reverse-video {
    background-color: #afff5f !important; }

.bg-color-156 {
  background-color: #afff87; }
  .bg-color-156.reverse-video {
    color: #afff87 !important; }

.fg-color-156 {
  color: #afff87; }
  .fg-color-156.reverse-video {
    background-color: #afff87 !important; }

.bg-color-157 {
  background-color: #afffaf; }
  .bg-color-157.reverse-video {
    color: #afffaf !important; }

.fg-color-157 {
  color: #afffaf; }
  .fg-color-157.reverse-video {
    background-color: #afffaf !important; }

.bg-color-158 {
  background-color: #afffd7; }
  .bg-color-158.reverse-video {
    color: #afffd7 !important; }

.fg-color-158 {
  color: #afffd7; }
  .fg-color-158.reverse-video {
    background-color: #afffd7 !important; }

.bg-color-159 {
  background-color: #afffff; }
  .bg-color-159.reverse-video {
    color: #afffff !important; }

.fg-color-159 {
  color: #afffff; }
  .fg-color-159.reverse-video {
    background-color: #afffff !important; }

.bg-color-160 {
  background-color: #d70000; }
  .bg-color-160.reverse-video {
    color: #d70000 !important; }

.fg-color-160 {
  color: #d70000; }
  .fg-color-160.reverse-video {
    background-color: #d70000 !important; }

.bg-color-161 {
  background-color: #d7005f; }
  .bg-color-161.reverse-video {
    color: #d7005f !important; }

.fg-color-161 {
  color: #d7005f; }
  .fg-color-161.reverse-video {
    background-color: #d7005f !important; }

.bg-color-162 {
  background-color: #d70087; }
  .bg-color-162.reverse-video {
    color: #d70087 !important; }

.fg-color-162 {
  color: #d70087; }
  .fg-color-162.reverse-video {
    background-color: #d70087 !important; }

.bg-color-163 {
  background-color: #d700af; }
  .bg-color-163.reverse-video {
    color: #d700af !important; }

.fg-color-163 {
  color: #d700af; }
  .fg-color-163.reverse-video {
    background-color: #d700af !important; }

.bg-color-164 {
  background-color: #d700d7; }
  .bg-color-164.reverse-video {
    color: #d700d7 !important; }

.fg-color-164 {
  color: #d700d7; }
  .fg-color-164.reverse-video {
    background-color: #d700d7 !important; }

.bg-color-165 {
  background-color: #d700ff; }
  .bg-color-165.reverse-video {
    color: #d700ff !important; }

.fg-color-165 {
  color: #d700ff; }
  .fg-color-165.reverse-video {
    background-color: #d700ff !important; }

.bg-color-166 {
  background-color: #d75f00; }
  .bg-color-166.reverse-video {
    color: #d75f00 !important; }

.fg-color-166 {
  color: #d75f00; }
  .fg-color-166.reverse-video {
    background-color: #d75f00 !important; }

.bg-color-167 {
  background-color: #d75f5f; }
  .bg-color-167.reverse-video {
    color: #d75f5f !important; }

.fg-color-167 {
  color: #d75f5f; }
  .fg-color-167.reverse-video {
    background-color: #d75f5f !important; }

.bg-color-168 {
  background-color: #d75f87; }
  .bg-color-168.reverse-video {
    color: #d75f87 !important; }

.fg-color-168 {
  color: #d75f87; }
  .fg-color-168.reverse-video {
    background-color: #d75f87 !important; }

.bg-color-169 {
  background-color: #d75faf; }
  .bg-color-169.reverse-video {
    color: #d75faf !important; }

.fg-color-169 {
  color: #d75faf; }
  .fg-color-169.reverse-video {
    background-color: #d75faf !important; }

.bg-color-170 {
  background-color: #d75fd7; }
  .bg-color-170.reverse-video {
    color: #d75fd7 !important; }

.fg-color-170 {
  color: #d75fd7; }
  .fg-color-170.reverse-video {
    background-color: #d75fd7 !important; }

.bg-color-171 {
  background-color: #d75fff; }
  .bg-color-171.reverse-video {
    color: #d75fff !important; }

.fg-color-171 {
  color: #d75fff; }
  .fg-color-171.reverse-video {
    background-color: #d75fff !important; }

.bg-color-172 {
  background-color: #d78700; }
  .bg-color-172.reverse-video {
    color: #d78700 !important; }

.fg-color-172 {
  color: #d78700; }
  .fg-color-172.reverse-video {
    background-color: #d78700 !important; }

.bg-color-173 {
  background-color: #d7875f; }
  .bg-color-173.reverse-video {
    color: #d7875f !important; }

.fg-color-173 {
  color: #d7875f; }
  .fg-color-173.reverse-video {
    background-color: #d7875f !important; }

.bg-color-174 {
  background-color: #d78787; }
  .bg-color-174.reverse-video {
    color: #d78787 !important; }

.fg-color-174 {
  color: #d78787; }
  .fg-color-174.reverse-video {
    background-color: #d78787 !important; }

.bg-color-175 {
  background-color: #d787af; }
  .bg-color-175.reverse-video {
    color: #d787af !important; }

.fg-color-175 {
  color: #d787af; }
  .fg-color-175.reverse-video {
    background-color: #d787af !important; }

.bg-color-176 {
  background-color: #d787d7; }
  .bg-color-176.reverse-video {
    color: #d787d7 !important; }

.fg-color-176 {
  color: #d787d7; }
  .fg-color-176.reverse-video {
    background-color: #d787d7 !important; }

.bg-color-177 {
  background-color: #d787ff; }
  .bg-color-177.reverse-video {
    color: #d787ff !important; }

.fg-color-177 {
  color: #d787ff; }
  .fg-color-177.reverse-video {
    background-color: #d787ff !important; }

.bg-color-178 {
  background-color: #d7af00; }
  .bg-color-178.reverse-video {
    color: #d7af00 !important; }

.fg-color-178 {
  color: #d7af00; }
  .fg-color-178.reverse-video {
    background-color: #d7af00 !important; }

.bg-color-179 {
  background-color: #d7af5f; }
  .bg-color-179.reverse-video {
    color: #d7af5f !important; }

.fg-color-179 {
  color: #d7af5f; }
  .fg-color-179.reverse-video {
    background-color: #d7af5f !important; }

.bg-color-180 {
  background-color: #d7af87; }
  .bg-color-180.reverse-video {
    color: #d7af87 !important; }

.fg-color-180 {
  color: #d7af87; }
  .fg-color-180.reverse-video {
    background-color: #d7af87 !important; }

.bg-color-181 {
  background-color: #d7afaf; }
  .bg-color-181.reverse-video {
    color: #d7afaf !important; }

.fg-color-181 {
  color: #d7afaf; }
  .fg-color-181.reverse-video {
    background-color: #d7afaf !important; }

.bg-color-182 {
  background-color: #d7afd7; }
  .bg-color-182.reverse-video {
    color: #d7afd7 !important; }

.fg-color-182 {
  color: #d7afd7; }
  .fg-color-182.reverse-video {
    background-color: #d7afd7 !important; }

.bg-color-183 {
  background-color: #d7afff; }
  .bg-color-183.reverse-video {
    color: #d7afff !important; }

.fg-color-183 {
  color: #d7afff; }
  .fg-color-183.reverse-video {
    background-color: #d7afff !important; }

.bg-color-184 {
  background-color: #d7d700; }
  .bg-color-184.reverse-video {
    color: #d7d700 !important; }

.fg-color-184 {
  color: #d7d700; }
  .fg-color-184.reverse-video {
    background-color: #d7d700 !important; }

.bg-color-185 {
  background-color: #d7d75f; }
  .bg-color-185.reverse-video {
    color: #d7d75f !important; }

.fg-color-185 {
  color: #d7d75f; }
  .fg-color-185.reverse-video {
    background-color: #d7d75f !important; }

.bg-color-186 {
  background-color: #d7d787; }
  .bg-color-186.reverse-video {
    color: #d7d787 !important; }

.fg-color-186 {
  color: #d7d787; }
  .fg-color-186.reverse-video {
    background-color: #d7d787 !important; }

.bg-color-187 {
  background-color: #d7d7af; }
  .bg-color-187.reverse-video {
    color: #d7d7af !important; }

.fg-color-187 {
  color: #d7d7af; }
  .fg-color-187.reverse-video {
    background-color: #d7d7af !important; }

.bg-color-188 {
  background-color: #d7d7d7; }
  .bg-color-188.reverse-video {
    color: #d7d7d7 !important; }

.fg-color-188 {
  color: #d7d7d7; }
  .fg-color-188.reverse-video {
    background-color: #d7d7d7 !important; }

.bg-color-189 {
  background-color: #d7d7ff; }
  .bg-color-189.reverse-video {
    color: #d7d7ff !important; }

.fg-color-189 {
  color: #d7d7ff; }
  .fg-color-189.reverse-video {
    background-color: #d7d7ff !important; }

.bg-color-190 {
  background-color: #d7ff00; }
  .bg-color-190.reverse-video {
    color: #d7ff00 !important; }

.fg-color-190 {
  color: #d7ff00; }
  .fg-color-190.reverse-video {
    background-color: #d7ff00 !important; }

.bg-color-191 {
  background-color: #d7ff5f; }
  .bg-color-191.reverse-video {
    color: #d7ff5f !important; }

.fg-color-191 {
  color: #d7ff5f; }
  .fg-color-191.reverse-video {
    background-color: #d7ff5f !important; }

.bg-color-192 {
  background-color: #d7ff87; }
  .bg-color-192.reverse-video {
    color: #d7ff87 !important; }

.fg-color-192 {
  color: #d7ff87; }
  .fg-color-192.reverse-video {
    background-color: #d7ff87 !important; }

.bg-color-193 {
  background-color: #d7ffaf; }
  .bg-color-193.reverse-video {
    color: #d7ffaf !important; }

.fg-color-193 {
  color: #d7ffaf; }
  .fg-color-193.reverse-video {
    background-color: #d7ffaf !important; }

.bg-color-194 {
  background-color: #d7ffd7; }
  .bg-color-194.reverse-video {
    color: #d7ffd7 !important; }

.fg-color-194 {
  color: #d7ffd7; }
  .fg-color-194.reverse-video {
    background-color: #d7ffd7 !important; }

.bg-color-195 {
  background-color: #d7ffff; }
  .bg-color-195.reverse-video {
    color: #d7ffff !important; }

.fg-color-195 {
  color: #d7ffff; }
  .fg-color-195.reverse-video {
    background-color: #d7ffff !important; }

.bg-color-196 {
  background-color: red; }
  .bg-color-196.reverse-video {
    color: red !important; }

.fg-color-196 {
  color: red; }
  .fg-color-196.reverse-video {
    background-color: red !important; }

.bg-color-197 {
  background-color: #ff005f; }
  .bg-color-197.reverse-video {
    color: #ff005f !important; }

.fg-color-197 {
  color: #ff005f; }
  .fg-color-197.reverse-video {
    background-color: #ff005f !important; }

.bg-color-198 {
  background-color: #ff0087; }
  .bg-color-198.reverse-video {
    color: #ff0087 !important; }

.fg-color-198 {
  color: #ff0087; }
  .fg-color-198.reverse-video {
    background-color: #ff0087 !important; }

.bg-color-199 {
  background-color: #ff00af; }
  .bg-color-199.reverse-video {
    color: #ff00af !important; }

.fg-color-199 {
  color: #ff00af; }
  .fg-color-199.reverse-video {
    background-color: #ff00af !important; }

.bg-color-200 {
  background-color: #ff00d7; }
  .bg-color-200.reverse-video {
    color: #ff00d7 !important; }

.fg-color-200 {
  color: #ff00d7; }
  .fg-color-200.reverse-video {
    background-color: #ff00d7 !important; }

.bg-color-201 {
  background-color: magenta; }
  .bg-color-201.reverse-video {
    color: magenta !important; }

.fg-color-201 {
  color: magenta; }
  .fg-color-201.reverse-video {
    background-color: magenta !important; }

.bg-color-202 {
  background-color: #ff5f00; }
  .bg-color-202.reverse-video {
    color: #ff5f00 !important; }

.fg-color-202 {
  color: #ff5f00; }
  .fg-color-202.reverse-video {
    background-color: #ff5f00 !important; }

.bg-color-203 {
  background-color: #ff5f5f; }
  .bg-color-203.reverse-video {
    color: #ff5f5f !important; }

.fg-color-203 {
  color: #ff5f5f; }
  .fg-color-203.reverse-video {
    background-color: #ff5f5f !important; }

.bg-color-204 {
  background-color: #ff5f87; }
  .bg-color-204.reverse-video {
    color: #ff5f87 !important; }

.fg-color-204 {
  color: #ff5f87; }
  .fg-color-204.reverse-video {
    background-color: #ff5f87 !important; }

.bg-color-205 {
  background-color: #ff5faf; }
  .bg-color-205.reverse-video {
    color: #ff5faf !important; }

.fg-color-205 {
  color: #ff5faf; }
  .fg-color-205.reverse-video {
    background-color: #ff5faf !important; }

.bg-color-206 {
  background-color: #ff5fd7; }
  .bg-color-206.reverse-video {
    color: #ff5fd7 !important; }

.fg-color-206 {
  color: #ff5fd7; }
  .fg-color-206.reverse-video {
    background-color: #ff5fd7 !important; }

.bg-color-207 {
  background-color: #ff5fff; }
  .bg-color-207.reverse-video {
    color: #ff5fff !important; }

.fg-color-207 {
  color: #ff5fff; }
  .fg-color-207.reverse-video {
    background-color: #ff5fff !important; }

.bg-color-208 {
  background-color: #ff8700; }
  .bg-color-208.reverse-video {
    color: #ff8700 !important; }

.fg-color-208 {
  color: #ff8700; }
  .fg-color-208.reverse-video {
    background-color: #ff8700 !important; }

.bg-color-209 {
  background-color: #ff875f; }
  .bg-color-209.reverse-video {
    color: #ff875f !important; }

.fg-color-209 {
  color: #ff875f; }
  .fg-color-209.reverse-video {
    background-color: #ff875f !important; }

.bg-color-210 {
  background-color: #ff8787; }
  .bg-color-210.reverse-video {
    color: #ff8787 !important; }

.fg-color-210 {
  color: #ff8787; }
  .fg-color-210.reverse-video {
    background-color: #ff8787 !important; }

.bg-color-211 {
  background-color: #ff87af; }
  .bg-color-211.reverse-video {
    color: #ff87af !important; }

.fg-color-211 {
  color: #ff87af; }
  .fg-color-211.reverse-video {
    background-color: #ff87af !important; }

.bg-color-212 {
  background-color: #ff87d7; }
  .bg-color-212.reverse-video {
    color: #ff87d7 !important; }

.fg-color-212 {
  color: #ff87d7; }
  .fg-color-212.reverse-video {
    background-color: #ff87d7 !important; }

.bg-color-213 {
  background-color: #ff87ff; }
  .bg-color-213.reverse-video {
    color: #ff87ff !important; }

.fg-color-213 {
  color: #ff87ff; }
  .fg-color-213.reverse-video {
    background-color: #ff87ff !important; }

.bg-color-214 {
  background-color: #ffaf00; }
  .bg-color-214.reverse-video {
    color: #ffaf00 !important; }

.fg-color-214 {
  color: #ffaf00; }
  .fg-color-214.reverse-video {
    background-color: #ffaf00 !important; }

.bg-color-215 {
  background-color: #ffaf5f; }
  .bg-color-215.reverse-video {
    color: #ffaf5f !important; }

.fg-color-215 {
  color: #ffaf5f; }
  .fg-color-215.reverse-video {
    background-color: #ffaf5f !important; }

.bg-color-216 {
  background-color: #ffaf87; }
  .bg-color-216.reverse-video {
    color: #ffaf87 !important; }

.fg-color-216 {
  color: #ffaf87; }
  .fg-color-216.reverse-video {
    background-color: #ffaf87 !important; }

.bg-color-217 {
  background-color: #ffafaf; }
  .bg-color-217.reverse-video {
    color: #ffafaf !important; }

.fg-color-217 {
  color: #ffafaf; }
  .fg-color-217.reverse-video {
    background-color: #ffafaf !important; }

.bg-color-218 {
  background-color: #ffafd7; }
  .bg-color-218.reverse-video {
    color: #ffafd7 !important; }

.fg-color-218 {
  color: #ffafd7; }
  .fg-color-218.reverse-video {
    background-color: #ffafd7 !important; }

.bg-color-219 {
  background-color: #ffafff; }
  .bg-color-219.reverse-video {
    color: #ffafff !important; }

.fg-color-219 {
  color: #ffafff; }
  .fg-color-219.reverse-video {
    background-color: #ffafff !important; }

.bg-color-220 {
  background-color: gold; }
  .bg-color-220.reverse-video {
    color: gold !important; }

.fg-color-220 {
  color: gold; }
  .fg-color-220.reverse-video {
    background-color: gold !important; }

.bg-color-221 {
  background-color: #ffd75f; }
  .bg-color-221.reverse-video {
    color: #ffd75f !important; }

.fg-color-221 {
  color: #ffd75f; }
  .fg-color-221.reverse-video {
    background-color: #ffd75f !important; }

.bg-color-222 {
  background-color: #ffd787; }
  .bg-color-222.reverse-video {
    color: #ffd787 !important; }

.fg-color-222 {
  color: #ffd787; }
  .fg-color-222.reverse-video {
    background-color: #ffd787 !important; }

.bg-color-223 {
  background-color: #ffd7af; }
  .bg-color-223.reverse-video {
    color: #ffd7af !important; }

.fg-color-223 {
  color: #ffd7af; }
  .fg-color-223.reverse-video {
    background-color: #ffd7af !important; }

.bg-color-224 {
  background-color: #ffd7d7; }
  .bg-color-224.reverse-video {
    color: #ffd7d7 !important; }

.fg-color-224 {
  color: #ffd7d7; }
  .fg-color-224.reverse-video {
    background-color: #ffd7d7 !important; }

.bg-color-225 {
  background-color: #ffd7ff; }
  .bg-color-225.reverse-video {
    color: #ffd7ff !important; }

.fg-color-225 {
  color: #ffd7ff; }
  .fg-color-225.reverse-video {
    background-color: #ffd7ff !important; }

.bg-color-226 {
  background-color: yellow; }
  .bg-color-226.reverse-video {
    color: yellow !important; }

.fg-color-226 {
  color: yellow; }
  .fg-color-226.reverse-video {
    background-color: yellow !important; }

.bg-color-227 {
  background-color: #ffff5f; }
  .bg-color-227.reverse-video {
    color: #ffff5f !important; }

.fg-color-227 {
  color: #ffff5f; }
  .fg-color-227.reverse-video {
    background-color: #ffff5f !important; }

.bg-color-228 {
  background-color: #ffff87; }
  .bg-color-228.reverse-video {
    color: #ffff87 !important; }

.fg-color-228 {
  color: #ffff87; }
  .fg-color-228.reverse-video {
    background-color: #ffff87 !important; }

.bg-color-229 {
  background-color: #ffffaf; }
  .bg-color-229.reverse-video {
    color: #ffffaf !important; }

.fg-color-229 {
  color: #ffffaf; }
  .fg-color-229.reverse-video {
    background-color: #ffffaf !important; }

.bg-color-230 {
  background-color: #ffffd7; }
  .bg-color-230.reverse-video {
    color: #ffffd7 !important; }

.fg-color-230 {
  color: #ffffd7; }
  .fg-color-230.reverse-video {
    background-color: #ffffd7 !important; }

.bg-color-231 {
  background-color: white; }
  .bg-color-231.reverse-video {
    color: white !important; }

.fg-color-231 {
  color: white; }
  .fg-color-231.reverse-video {
    background-color: white !important; }

.bg-color-232 {
  background-color: #080808; }
  .bg-color-232.reverse-video {
    color: #080808 !important; }

.fg-color-232 {
  color: #080808; }
  .fg-color-232.reverse-video {
    background-color: #080808 !important; }

.bg-color-233 {
  background-color: #121212; }
  .bg-color-233.reverse-video {
    color: #121212 !important; }

.fg-color-233 {
  color: #121212; }
  .fg-color-233.reverse-video {
    background-color: #121212 !important; }

.bg-color-234 {
  background-color: #1c1c1c; }
  .bg-color-234.reverse-video {
    color: #1c1c1c !important; }

.fg-color-234 {
  color: #1c1c1c; }
  .fg-color-234.reverse-video {
    background-color: #1c1c1c !important; }

.bg-color-235 {
  background-color: #262626; }
  .bg-color-235.reverse-video {
    color: #262626 !important; }

.fg-color-235 {
  color: #262626; }
  .fg-color-235.reverse-video {
    background-color: #262626 !important; }

.bg-color-236 {
  background-color: #303030; }
  .bg-color-236.reverse-video {
    color: #303030 !important; }

.fg-color-236 {
  color: #303030; }
  .fg-color-236.reverse-video {
    background-color: #303030 !important; }

.bg-color-237 {
  background-color: #3a3a3a; }
  .bg-color-237.reverse-video {
    color: #3a3a3a !important; }

.fg-color-237 {
  color: #3a3a3a; }
  .fg-color-237.reverse-video {
    background-color: #3a3a3a !important; }

.bg-color-238 {
  background-color: #444444; }
  .bg-color-238.reverse-video {
    color: #444444 !important; }

.fg-color-238 {
  color: #444444; }
  .fg-color-238.reverse-video {
    background-color: #444444 !important; }

.bg-color-239 {
  background-color: #4e4e4e; }
  .bg-color-239.reverse-video {
    color: #4e4e4e !important; }

.fg-color-239 {
  color: #4e4e4e; }
  .fg-color-239.reverse-video {
    background-color: #4e4e4e !important; }

.bg-color-240 {
  background-color: #585858; }
  .bg-color-240.reverse-video {
    color: #585858 !important; }

.fg-color-240 {
  color: #585858; }
  .fg-color-240.reverse-video {
    background-color: #585858 !important; }

.bg-color-241 {
  background-color: #626262; }
  .bg-color-241.reverse-video {
    color: #626262 !important; }

.fg-color-241 {
  color: #626262; }
  .fg-color-241.reverse-video {
    background-color: #626262 !important; }

.bg-color-242 {
  background-color: #6c6c6c; }
  .bg-color-242.reverse-video {
    color: #6c6c6c !important; }

.fg-color-242 {
  color: #6c6c6c; }
  .fg-color-242.reverse-video {
    background-color: #6c6c6c !important; }

.bg-color-243 {
  background-color: #767676; }
  .bg-color-243.reverse-video {
    color: #767676 !important; }

.fg-color-243 {
  color: #767676; }
  .fg-color-243.reverse-video {
    background-color: #767676 !important; }

.bg-color-244 {
  background-color: gray; }
  .bg-color-244.reverse-video {
    color: gray !important; }

.fg-color-244 {
  color: gray; }
  .fg-color-244.reverse-video {
    background-color: gray !important; }

.bg-color-245 {
  background-color: #8a8a8a; }
  .bg-color-245.reverse-video {
    color: #8a8a8a !important; }

.fg-color-245 {
  color: #8a8a8a; }
  .fg-color-245.reverse-video {
    background-color: #8a8a8a !important; }

.bg-color-246 {
  background-color: #949494; }
  .bg-color-246.reverse-video {
    color: #949494 !important; }

.fg-color-246 {
  color: #949494; }
  .fg-color-246.reverse-video {
    background-color: #949494 !important; }

.bg-color-247 {
  background-color: #9e9e9e; }
  .bg-color-247.reverse-video {
    color: #9e9e9e !important; }

.fg-color-247 {
  color: #9e9e9e; }
  .fg-color-247.reverse-video {
    background-color: #9e9e9e !important; }

.bg-color-248 {
  background-color: #a8a8a8; }
  .bg-color-248.reverse-video {
    color: #a8a8a8 !important; }

.fg-color-248 {
  color: #a8a8a8; }
  .fg-color-248.reverse-video {
    background-color: #a8a8a8 !important; }

.bg-color-249 {
  background-color: #b2b2b2; }
  .bg-color-249.reverse-video {
    color: #b2b2b2 !important; }

.fg-color-249 {
  color: #b2b2b2; }
  .fg-color-249.reverse-video {
    background-color: #b2b2b2 !important; }

.bg-color-250 {
  background-color: #bcbcbc; }
  .bg-color-250.reverse-video {
    color: #bcbcbc !important; }

.fg-color-250 {
  color: #bcbcbc; }
  .fg-color-250.reverse-video {
    background-color: #bcbcbc !important; }

.bg-color-251 {
  background-color: #c6c6c6; }
  .bg-color-251.reverse-video {
    color: #c6c6c6 !important; }

.fg-color-251 {
  color: #c6c6c6; }
  .fg-color-251.reverse-video {
    background-color: #c6c6c6 !important; }

.bg-color-252 {
  background-color: #d0d0d0; }
  .bg-color-252.reverse-video {
    color: #d0d0d0 !important; }

.fg-color-252 {
  color: #d0d0d0; }
  .fg-color-252.reverse-video {
    background-color: #d0d0d0 !important; }

.bg-color-253 {
  background-color: #dadada; }
  .bg-color-253.reverse-video {
    color: #dadada !important; }

.fg-color-253 {
  color: #dadada; }
  .fg-color-253.reverse-video {
    background-color: #dadada !important; }

.bg-color-254 {
  background-color: #e4e4e4; }
  .bg-color-254.reverse-video {
    color: #e4e4e4 !important; }

.fg-color-254 {
  color: #e4e4e4; }
  .fg-color-254.reverse-video {
    background-color: #e4e4e4 !important; }

.bg-color-255 {
  background-color: #eeeeee; }
  .bg-color-255.reverse-video {
    color: #eeeeee !important; }

.fg-color-255 {
  color: #eeeeee; }
  .fg-color-255.reverse-video {
    background-color: #eeeeee !important; }

.bg-color-256 {
  background-color: transparent; }
  .bg-color-256.reverse-video {
    color: #110f13 !important; }

.fg-color-256 {
  color: transparent; }
  .fg-color-256.reverse-video {
    background-color: transparent !important; }

.bg-color-257 {
  background-color: #f4ead5; }
  .bg-color-257.reverse-video {
    color: #f4ead5 !important; }

.fg-color-257 {
  color: #f4ead5; }
  .fg-color-257.reverse-video {
    background-color: #f4ead5 !important; }

/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */
/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */
/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */
/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
html, body {
  margin: 0;
  padding: 0;
  background-color: #110f13;
  color: #f4ead5; }

body {
  white-space: nowrap;
  overflow-x: hidden;
  overflow-y: scroll;
  /* Pop ups */ }
  body .line.active {
    background-color: transparent; }
  body .line.extended {
    overflow-x: auto;
    overflow-x: overlay;
    cursor: zoom-in;
    background-image: linear-gradient(90deg, rgba(9, 8, 10, 0), 95%, #09080a); }
    body .line.extended:not(.expanded):hover {
      background-color: #161419; }
    body .line.extended.expanded {
      cursor: zoom-out;
      background-color: #09080a; }
      body .line.extended.expanded .extra {
        display: block;
        white-space: pre-line;
        word-break: break-all; }
    body .line.extended::-webkit-scrollbar {
      background: rgba(17, 15, 19, 0.1);
      height: 0; }
    body .line.extended::-webkit-scrollbar-thumb {
      background: rgba(244, 234, 213, 0.1); }
    body .line.extended::-webkit-scrollbar-thumb:hover {
      background: rgba(244, 234, 213, 0.1); }
  body::-webkit-scrollbar {
    background: #110f13;
    width: 0.75em; }
  body::-webkit-scrollbar-thumb {
    background: rgba(244, 234, 213, 0.1); }
  body::-webkit-scrollbar-thumb:hover {
    background: rgba(244, 234, 213, 0.1); }
  body .hidden {
    display: none !important; }
  body #popup {
    position: fixed;
    display: flex;
    align-items: center;
    justify-content: center;
    width: 100%;
    height: 100%; }
    body #popup form, body #popup > div {
      padding: 1.5em;
      background: rgba(127, 127, 127, 0.5);
      color: #f4ead5;
      font-size: 1em; }
      body #popup form h2, body #popup > div h2 {
        margin: 0 .5em .5em .5em; }
      body #popup form select, body #popup > div select {
        min-width: 300px;
        padding: .5em;
        width: 100%; }
      body #popup form label, body #popup > div label {
        display: block;
        padding: .5em;
        font-size: .75em; }

.terminal {
  outline: none; }

/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */
/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */
/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */
/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
.focus .cursor {
  transition: 300ms; }

.cursor.reverse-video {
  box-shadow: 0 0 0 #f4ead5; }

/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */
/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */
/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */
/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
.bold {
  font-weight: bold; }

.underline, .nbsp {
  text-decoration: underline; }

.italic {
  font-style: italic; }

.faint {
  opacity: .6; }

.crossed {
  text-decoration: line-through; }

/* Not supported, emulated */
/* .blink */
/*   text-decoration: blink */
.blink {
  animation: blink 1s ease-in-out infinite; }

.blink-fast {
  animation: blink 250ms ease-in-out infinite; }

@keyframes blink {
  0% {
    opacity: 1; }
  50% {
    opacity: 0; }
  100% {
    opacity: 1; } }

.invisible {
  visibility: hidden; }

.reverse-video {
  color: #110f13;
  background-color: #f4ead5; }

.blur .cursor {
  border: 1px solid #f4ead5;
  background: none; }

.inline-html {
  overflow: hidden; }

.inline-image {
  max-width: 100%;
  max-height: 50vh; }

a {
  color: inherit; }
