/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */

/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */

/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */

/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */

html, body
  margin: 0
  padding: 0
  background-color: $bg
  color: $fg

body
  white-space: nowrap
  overflow-x: hidden
  overflow-y: scroll

  .line.active
    background-color: $active-bg

  .line.extended
    overflow-x: auto
    overflow-x: overlay
    cursor: zoom-in
    background-image: linear-gradient(90deg, rgba(darken($bg, 3%), 0), 95%, darken($bg, 3%))

    &:not(.expanded):hover
      background-color: lighten($bg, 2%)

    &.expanded
      cursor: zoom-out
      background-color: darken($bg, 3%)

      .extra
        display: block
        white-space: pre-line
        word-break: break-all

    &::-webkit-scrollbar
      background: rgba($scroll-bg, .1)
      height: 0

    &::-webkit-scrollbar-thumb
      background: rgba($scroll-fg, .1)

    &::-webkit-scrollbar-thumb:hover
      background: rgba($scroll-fg-hover, .1)

  &::-webkit-scrollbar
    background: $scroll-bg
    width: $scroll-width

  &::-webkit-scrollbar-thumb
    background: $scroll-fg

  &::-webkit-scrollbar-thumb:hover
    background: $scroll-fg-hover

  /* Pop ups */
  .hidden
    display: none !important

  #popup
    position: fixed
    display: flex
    align-items: center
    justify-content: center
    width: 100%
    height: 100%

    form, > div
      padding: 1.5em
      background: $popup-bg
      color: $popup-fg
      font-size: $popup-fs

      h2
        margin: 0 .5em .5em .5em
      select
        min-width: 300px
        padding: .5em
        width: 100%
      label
        display: block
        padding: .5em
        font-size: .75em

.terminal
  outline: none
