/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */

/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */

/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */

/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */

.bold
  font-weight: bold

.underline
  text-decoration: underline

.italic
  font-style: italic

.faint
  opacity: .6

.crossed
  text-decoration: line-through

/* Not supported, emulated
/* .blink
/*   text-decoration: blink
.blink
  animation: blink 1s ease-in-out infinite

.blink-fast
  animation: blink 250ms ease-in-out infinite

@keyframes blink
  0%
    opacity: 1
  50%
    opacity: 0
  100%
    opacity: 1

.invisible
  visibility: hidden

.reverse-video
  color: $bg
  background-color: $fg

.blur .cursor
  border: 1px solid $fg
  background: none

.nbsp
  @extend .underline
  @extend .fg-color-1

.inline-html
  overflow: hidden

.inline-image
  max-width: 100%
  max-height: 50vh

a
  color: inherit
