/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */

/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */

/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */

/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */

body
  transition: 200ms
  transform-origin: bottom

  &.bell
    -webkit-filter: blur(2px)
    filter: blur(2px)

  &.skip
    -webkit-filter: sepia(1)
    filter: sepia(1)

  &.selection
    -webkit-filter: saturate(2)
    filter: saturate(2)

  &.alarm
    -webkit-filter: hue-rotate(150deg)
    filter: hue-rotate(150deg)

  &.dead
    -webkit-filter: grayscale(1)
    filter: grayscale(1)

    &:after
      content: "CLOSED"
      font-size: 15em
      display: flex
      justify-content: center
      align-items: center
      position: fixed
      top: 0
      left: 0
      width: 100%
      height: 100%
      transform: rotate(-45deg)
      opacity: .2
      font-weight: 900

  &.stopped
    -webkit-filter: brightness(50%)
    filter: brightness(50%)

  &.locked
    &::-webkit-scrollbar-thumb
      background: rgba(red, .7)

    &::-webkit-scrollbar-thumb:hover
      background: rgba(red, .8)
