/* *-* coding: utf-8 *-* */
/* This file is part of butterfly */

/* butterfly Copyright (C) 2015  Florian Mounier */
/* This program is free software: you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or */
/* (at your option) any later version. */

/* This program is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */

/* You should have received a copy of the GNU General Public License */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */

/* Theses are the various imported style files
/* THIS NEEDS the python `libsass` library to be installed.
/* You can copy the imported files in the theme dir, they will be imported prioritarily.

/* You can change this file to import any webfont:
@import font

/* You can comment / uncomment the following to enable/disable terminal effects.
@import light_fx
/* Comment this one to remove the blurry text:
@import text_fx
/* @import all_fx

@import colors
/* The color theme is defined in this one:
@import 16_colors
@import 256_colors

@import layout
@import cursor
@import term_styles
